/**************************************************************************/
/* tg_disp.c -  Functions relating to displaying info for individual      */
/*                episodes or actors, for the "Trek Guru" program.        */
/*                                                                        */
/*                Original creator: Rob Seace (ras@world.std.com)         */
/*                                                                        */
/*        Note: If you make ANY changes at all to any of the code, PLEASE */
/*              make note of it with comments, as well as in the "README" */
/*              file, especially if re-distributing the new code.         */
/**************************************************************************/


#include "trekguru.h"


/* tg_display_act - Displays the info in the passed actor record, then
                    pauses and prompts for input.  If the user enters 'q',
                    the program returns TRUE (a signal that they want to
                    stop the search); if they enter 's', the program
                    prompts for a filename, then saves the current info
                    to that file (appending), then re-prompts for more
                    input; if they enter anything other than 'q' or 's',
                    the program returns FALSE (a signal that they want to
                    go on to the next matching record, if there is one).
*/

int tg_display_act (rec)
    actrec    rec;                    /* a single actor record            */
{
    char    buf[MAX_BUF_LEN+1];       /* input buffer for user input      */

    for (;;) {
        printf ("\f\n\n");

        printf ("    ACTOR: %-*.*s\n\n", TG_ACTOR_LEN, TG_ACTOR_LEN, rec->actor);

        printf ("CHARACTER: %-*.*s\n\n", TG_CHAR_LEN, TG_CHAR_LEN, rec->character);

        printf (" EPISODES: %-*.*s\n\n", TG_EPS_LEN, TG_EPS_LEN, rec->episodes);

        printf ("\n\nEnter 's' to save this information to an ASCII file, 'q' to quit searching,\n");
        printf ("or just press ENTER to go to the next match (if there is one).\n\n");

        printf ("Command: ");
        fgets (buf, MAX_BUF_LEN, stdin);

        if ((buf[0] IS 'q') OR (buf[0] IS 'Q'))
            return (TRUE);
        else if ((buf[0] IS 's') OR (buf[0] IS 'S'))
            tg_save_act (rec);
        else
            return (FALSE);
    }
}

/* tg_save_act - Saves the info in the passed actor record to an ASCII
                 file.  If the file exists, it is appended.
*/

void tg_save_act (rec)
    actrec    rec;                      /* a single actor record            */
{
    char    fname[MAX_BUF_LEN+1];       /* the input file name              */
    FILE    *fp;                        /* file pointer to the save file    */

    printf ("\n\nEnter a file name: ");
    fgets (fname, MAX_BUF_LEN, stdin);
    fname[strlen (fname) - 1] = '\0';    /* get rid of '\n' */

    if ((fp = fopen (fname, "a")) IS NULL) {
        printf ("\07\nCan't open file (%s)!  Press ENTER.", fname);
        fgets (fname, MAX_BUF_LEN, stdin);
        return;
    }

    fprintf (fp, "------------------------------------------------------------------------------\n\n");

    fprintf (fp, "    ACTOR: %-*.*s\n\n", TG_ACTOR_LEN, TG_ACTOR_LEN,
                                            rec->actor);

    fprintf (fp, "CHARACTER: %-*.*s\n\n", TG_CHAR_LEN, TG_CHAR_LEN,
                                            rec->character);

    fprintf (fp, " EPISODES: %-*.*s\n\n", TG_EPS_LEN, TG_EPS_LEN,
                                            rec->episodes);

    fclose (fp);
}

    

/* tg_display_eps - Displays the info in the passed episode record, then
                    pauses and prompts for input.  If the user enters 'q',
                    the program returns TRUE (a signal that they want to
                    stop the search); if they enter 's', the program
                    prompts for a filename, then saves the current info
                    to that file (appending), then re-prompts for more
                    input; if they enter anything other than 'q' or 's',
                    the program returns FALSE (a signal that they want to
                    go on to the next matching record, if there is one).
*/

int tg_display_eps (rec)
    epsrec    rec;                    /* a single episode record            */
{
    char    buf[MAX_BUF_LEN+1];       /* input buffer for user input        */

    for (;;) {
        printf ("\f\n\n");

        printf ("  TITLE: %-*.*s\n\n", TG_TITLE_LEN, TG_TITLE_LEN, rec->title);

        printf (" NUMBER: %-*.*s    AIRDATE: %-*.*s    STARDATE: %-*.*s\n\n",
                    TG_NUMBER_LEN, TG_NUMBER_LEN, rec->number,
                    TG_AIRDATE_LEN, TG_AIRDATE_LEN, rec->airdate,
                    TG_STARDATE_LEN, TG_STARDATE_LEN, rec->stardate);

        printf (" WRITER: %-*.*s\n\n", TG_WRITER_LEN, TG_WRITER_LEN,
                                        rec->writer);

        printf ("DIRECTOR: %-*.*s\n\n", TG_DIRECTOR_LEN, TG_DIRECTOR_LEN,
                                        rec->director);

        printf ("SYNOPSIS:\n");

        printf ("%-*.*s\n", 79, 79, rec->synop1);    /* only 79, because real */
        printf ("%-*.*s\n", 79, 79, rec->synop2);    /* lengths of 80 scroll  */
        printf ("%-*.*s\n\n", TG_SYNOP3_LEN, TG_SYNOP3_LEN, rec->synop3);

        printf ("\nEnter 's' to save this information to an ASCII file, 'q' to quit searching,\n");
        printf ("or just press ENTER to go to the next match (if there is one).\n\n");

        printf ("Command: ");
        fgets (buf, MAX_BUF_LEN, stdin);

        if ((buf[0] IS 'q') OR (buf[0] IS 'Q'))
            return (TRUE);
        else if ((buf[0] IS 's') OR (buf[0] IS 'S'))
            tg_save_eps (rec);
        else
            return (FALSE);
    }
}

/* tg_save_eps - Saves the info in the passed episode record to an ASCII
                 file.  If the file exists, it is appended.
*/

void tg_save_eps (rec)
    epsrec    rec;                      /* a single episode record          */
{
    char    fname[MAX_BUF_LEN+1];       /* the input file name              */
    FILE    *fp;                        /* file pointer to the save file    */

    printf ("\n\nEnter a file name: ");
    fgets (fname, MAX_BUF_LEN, stdin);
    fname[strlen (fname) - 1] = '\0';    /* get rid of '\n' */

    if ((fp = fopen (fname, "a")) IS NULL) {
        printf ("\07\nCan't open file (%s)!  Press ENTER.", fname);
        fgets (fname, MAX_BUF_LEN, stdin);
        return;
    }

    fprintf (fp, "------------------------------------------------------------------------------\n\n");

    fprintf (fp, "  TITLE: %-*.*s\n\n", TG_TITLE_LEN, TG_TITLE_LEN, rec->title);

    fprintf (fp, " NUMBER: %-*.*s    AIRDATE: %-*.*s    STARDATE: %-*.*s\n\n",
                    TG_NUMBER_LEN, TG_NUMBER_LEN, rec->number,
                    TG_AIRDATE_LEN, TG_AIRDATE_LEN, rec->airdate,
                    TG_STARDATE_LEN, TG_STARDATE_LEN, rec->stardate);

    fprintf (fp, " WRITER: %-*.*s\n\n", TG_WRITER_LEN, TG_WRITER_LEN,
                                        rec->writer);

    fprintf (fp, "DIRECTOR: %-*.*s\n\n", TG_DIRECTOR_LEN, TG_DIRECTOR_LEN,
                                        rec->director);

    fprintf (fp, "SYNOPSIS:\n");

    fprintf (fp, "%-*.*s\n", 79, 79, rec->synop1);
    fprintf (fp, "%-*.*s\n", 79, 79, rec->synop2);
    fprintf (fp, "%-*.*s\n\n", TG_SYNOP3_LEN, TG_SYNOP3_LEN, rec->synop3);

    fclose (fp);
}

