/**************************************************************************/
/* tg_list.c -  Functions relating to listing the info for all            */
/*                episodes or actors, for the "Trek Guru" program.        */
/*                                                                        */
/*                Original creator: Rob Seace (ras@world.std.com)         */
/*                                                                        */
/*        Note: If you make ANY changes at all to any of the code, PLEASE */
/*              make note of it with comments, as well as in the "README" */
/*              file, especially if re-distributing the new code.         */
/**************************************************************************/


#include "trekguru.h"


/* tg_list_acts - Lists abbreviated info (actor and character names only, on
                  a single line each) for all actors/characters in currently
                  selected database(s).
*/

void tg_list_acts ()
{
    char    buf[MAX_BUF_LEN+1];      /* input buffer for user input      */
    int     i;                       /* loop counter                     */
    int     lc;                      /* line count                       */
    FILE    *fp;                     /* file pointer for output          */
    FILE    *ifp;                    /* file pointer for input file      */
struct actrec_struct    rec;         /* a single actor record            */

    printf ("\f\n\n");

    printf ("This will list the names of all actors and the characters they played,\n");
    printf ("in the currently selected database(s).  Enter 's' to save this information\n");
    printf ("in an ASCII file (with form-feeds, suitable for sending to a printer), 'q'\n");
    printf ("to return to the sub-menu, or just ENTER to display it on screen.\n\n");

    printf ("Command: ");
    fgets (buf, MAX_BUF_LEN, stdin);

    if ((buf[0] IS 'q') OR (buf[0] IS 'Q'))
        return;
    else if ((buf[0] IS 's') OR (buf[0] IS 'S')) {
        printf ("\nEnter the file name: ");
        fgets (buf, MAX_BUF_LEN, stdin);
        buf[strlen (buf) - 1] = '\0';    /* get rid of '\n' */
        if ((fp = fopen (buf, "a")) IS NULL) {
            printf ("\07\nCan't open file (%s)! Press ENTER to continue.", buf);
            fgets (buf, MAX_BUF_LEN, stdin);
            return;
        }
    } else
        fp = stdout;

    if (fp IS stdout)
        printf ("\f\n\n");

    fprintf (fp, "%-*.*s %-*.*s\n",
                        TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                        TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
    fprintf (fp, "------------------------------------------------------------------------------\n");

    lc = 0;

    if (UseMem) {
        for (i = 0; i < Num_Acts; i++) {
            lc++;

            if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                printf ("\nPress ENTER to continue, 'q' to quit: ");
                fgets (buf, MAX_BUF_LEN, stdin);

                if ((buf[0] IS 'q') OR (buf[0] IS 'Q'))
                    return;

                printf ("\f\n\n");
                fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                            TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                fprintf (fp, "------------------------------------------------------------------------------\n");
                lc = 0;
            } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                fprintf (fp, "\f\n\n");
                fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                            TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                fprintf (fp, "------------------------------------------------------------------------------\n");
                lc = 0;
            }

            fprintf (fp, "%-*.*s %-*.*s\n",
                        TG_ACTOR_LEN, TG_ACTOR_LEN, Acts[i].actor,
                        TG_CHAR_LEN, TG_CHAR_LEN, Acts[i].character);
        }
    } else {
        if (File_TOS) {
            if ((ifp = fopen (TG_FILE_ACT_TOS, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_ACTOR_LEN, TG_ACTOR_LEN, rec.actor,
                            TG_CHAR_LEN, TG_CHAR_LEN, rec.character);
                }

                fclose (ifp);
            }
        }

        if (File_TAS) {
            if ((ifp = fopen (TG_FILE_ACT_TAS, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_ACTOR_LEN, TG_ACTOR_LEN, rec.actor,
                            TG_CHAR_LEN, TG_CHAR_LEN, rec.character);
                }

                fclose (ifp);
            }
        }

        if (File_TMS) {
            if ((ifp = fopen (TG_FILE_ACT_TMS, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_ACTOR_LEN, TG_ACTOR_LEN, rec.actor,
                            TG_CHAR_LEN, TG_CHAR_LEN, rec.character);
                }

                fclose (ifp);
            }
        }

        if (File_TNG) {
            if ((ifp = fopen (TG_FILE_ACT_TNG, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_ACTOR_LEN, TG_ACTOR_LEN, rec.actor,
                            TG_CHAR_LEN, TG_CHAR_LEN, rec.character);
                }

                fclose (ifp);
            }
        }

        if (File_DS9) {
            if ((ifp = fopen (TG_FILE_ACT_DS9, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_ACTOR_LEN, TG_ACTOR_LEN, "Actor Name",
                                TG_CHAR_LEN, TG_CHAR_LEN, "Character Name");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_ACTOR_LEN, TG_ACTOR_LEN, rec.actor,
                            TG_CHAR_LEN, TG_CHAR_LEN, rec.character);
                }

                fclose (ifp);
            }
        }
    }

    printf ("\nFinished.  Press ENTER to continue.");
    fgets (buf, MAX_BUF_LEN, stdin);

    if (fp ISNT stdout) {
        fprintf (fp, "\f\r");
        fclose (fp);
    }
}


/* tg_list_eps - Lists abbreviated info (title and production # only, on
                 a single line each) for all episodes in currently
                 selected database(s).
*/

void tg_list_eps ()
{
    char    buf[MAX_BUF_LEN+1];     /* input buffer for user input       */
    int        i;                   /* loop counter                      */
    int        lc;                  /* line count                        */
    FILE    *fp;                    /* file pointer for output           */
    FILE    *ifp;                   /* file pointer for input file       */
struct epsrec_struct    rec;        /* a single episode record           */

    printf ("\f\n\n");

    printf ("This will list the titles and production numbers of all of the episodes\n");
    printf ("in the currently selected database(s).  Enter 's' to save this information\n");
    printf ("in an ASCII file (with form-feeds, suitable for sending to a printer), 'q'\n");
    printf ("to return to the sub-menu, or just ENTER to display it on screen.\n\n");

    printf ("Command: ");
    fgets (buf, MAX_BUF_LEN, stdin);

    if ((buf[0] IS 'q') OR (buf[0] IS 'Q'))
        return;
    else if ((buf[0] IS 's') OR (buf[0] IS 'S')) {
        printf ("\nEnter the file name: ");
        fgets (buf, MAX_BUF_LEN, stdin);
        buf[strlen (buf) - 1] = '\0';        /* get rid of '\n' */
        if ((fp = fopen (buf, "a")) IS NULL) {
            printf ("\07\nCan't open file (%s)! Press ENTER to continue.", buf);
            fgets (buf, MAX_BUF_LEN, stdin);
            return;
        }
    } else
        fp = stdout;

    if (fp IS stdout)
        printf ("\f\n\n");

    fprintf (fp, "%-*.*s %-*.*s\n",
                        TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                        TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
    fprintf (fp, "------------------------------------------------------------------------------\n");

    lc = 0;

    if (UseMem) {
        for (i = 0; i < Num_Eps; i++) {
            lc++;

            if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                printf ("\nPress ENTER to continue, 'q' to quit: ");
                fgets (buf, MAX_BUF_LEN, stdin);

                if ((buf[0] IS 'q') OR (buf[0] IS 'Q'))
                    return;

                printf ("\f\n\n");
                fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                            TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                fprintf (fp, "------------------------------------------------------------------------------\n");
                lc = 0;
            } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                fprintf (fp, "\f\n\n");
                fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                            TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                fprintf (fp, "------------------------------------------------------------------------------\n");
                lc = 0;
            }

            fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_NUMBER_LEN, TG_NUMBER_LEN, Eps[i].number,
                            TG_TITLE_LEN, TG_TITLE_LEN, Eps[i].title);
        }
    } else {
        if (File_TOS) {
            if ((ifp = fopen (TG_FILE_EPS_TOS, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_NUMBER_LEN, TG_NUMBER_LEN, rec.number,
                            TG_TITLE_LEN, TG_TITLE_LEN, rec.title);
                }

                fclose (ifp);
            }
        }

        if (File_TAS) {
            if ((ifp = fopen (TG_FILE_EPS_TAS, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_NUMBER_LEN, TG_NUMBER_LEN, rec.number,
                            TG_TITLE_LEN, TG_TITLE_LEN, rec.title);
                }

                fclose (ifp);
            }
        }

        if (File_TMS) {
            if ((ifp = fopen (TG_FILE_EPS_TMS, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_NUMBER_LEN, TG_NUMBER_LEN, rec.number,
                            TG_TITLE_LEN, TG_TITLE_LEN, rec.title);
                }

                fclose (ifp);
            }
        }

        if (File_TNG) {
            if ((ifp = fopen (TG_FILE_EPS_TNG, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_NUMBER_LEN, TG_NUMBER_LEN, rec.number,
                            TG_TITLE_LEN, TG_TITLE_LEN, rec.title);
                }

                fclose (ifp);
            }
        }

        if (File_DS9) {
            if ((ifp = fopen (TG_FILE_EPS_DS9, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, ifp) IS 1) {
                    lc++;

                    if ((fp IS stdout) AND (lc > TG_SCR_LINES)) {
                        printf ("\nPress ENTER to continue, 'q' to quit: ");
                        fgets (buf, MAX_BUF_LEN, stdin);

                        if ((buf[0] IS 'q') OR (buf[0] IS 'Q')) {
                            fclose (ifp);
                            return;
                        }

                        printf ("\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    } else if ((fp ISNT stdout) AND (lc > TG_PG_LINES)) {
                        fprintf (fp, "\f\n\n");
                        fprintf (fp, "%-*.*s %-*.*s\n",
                                TG_NUMBER_LEN, TG_NUMBER_LEN, "Number",
                                TG_TITLE_LEN, TG_TITLE_LEN, "Episode Title");
                        fprintf (fp, "------------------------------------------------------------------------------\n");
                        lc = 0;
                    }

                    fprintf (fp, "%-*.*s %-*.*s\n",
                            TG_NUMBER_LEN, TG_NUMBER_LEN, rec.number,
                            TG_TITLE_LEN, TG_TITLE_LEN, rec.title);
                }

                fclose (ifp);
            }
        }
    }

    printf ("\nFinished.  Press ENTER to continue.");
    fgets (buf, MAX_BUF_LEN, stdin);

    if (fp ISNT stdout) {
        fprintf (fp, "\f\r");
        fclose (fp);
    }
}

