/**************************************************************************/
/* tg_srch.c -  Functions relating to searching for particular episodes   */
/*                or actors/characters, for the "Trek Guru" program.      */
/*                                                                        */
/*                Original creator: Rob Seace (ras@world.std.com)         */
/*                                                                        */
/*        Note: If you make ANY changes at all to any of the code, PLEASE */
/*              make note of it with comments, as well as in the "README" */
/*              file, especially if re-distributing the new code.         */
/**************************************************************************/


#include "trekguru.h"


/* tg_search_act - Searches through the selected Actor database(s) (all in
                    Acts, if UseMem, else in the selected File_* files),
                    for a particular actor/character record, which matches
                    either the entered actor name, character name, or
                    episodes appeared in (depending on passed search_type).
*/

void tg_search_act (search_type)
    int        search_type;          /* the type of search being done    */
{
    char    srch_str[MAX_BUF_LEN+1]; /* buffer to hold input search str  */
    char    *match_str;              /* pointer to string in database    */
    int     i;                       /* loop counter                     */
    int     m_str_len;               /* length of match_str field        */
    FILE    *fp;                     /* file pointer; for NOT UseMem     */
    struct actrec_struct    rec;     /* a single actor record            */

    printf ("\f\n\n");

    if (search_type IS TG_SRCH_BY_NONE) {    /* find all records */
        m_str_len = 0;
        match_str = NULL;
        srch_str[0] = '\0';
    } else if (search_type IS TG_SRCH_BY_ACT) {
        printf ("Enter the actor name: ");
        m_str_len = TG_ACTOR_LEN;
    } else if (search_type IS TG_SRCH_BY_CHAR) {
        printf ("Enter the character name: ");
        m_str_len = TG_CHAR_LEN;
    } else if (search_type IS TG_SRCH_BY_EPS) {
        printf ("Enter the episode(s) appeared in: ");
        m_str_len = TG_EPS_LEN;
    } else            /* should never happen */
        return;

    if (search_type ISNT TG_SRCH_BY_NONE)
        fgets (srch_str, MAX_BUF_LEN, stdin);

    srch_str[strlen (srch_str) - 1] = '\0';        /* get rid of '\n' */

    if (UseMem) {
        for (i = 0; i < Num_Acts; i++) {
            if (search_type IS TG_SRCH_BY_ACT)
                match_str = Acts[i].actor;
            else if (search_type IS TG_SRCH_BY_CHAR)
                match_str = Acts[i].character;
            else if (search_type IS TG_SRCH_BY_EPS)
                match_str = Acts[i].episodes;

            if ((search_type IS TG_SRCH_BY_NONE) OR (tg_streq (srch_str, match_str, m_str_len))) {
                if (tg_display_act (&(Acts[i])))
                    return;
            }
        }
    } else {
        if (search_type IS TG_SRCH_BY_ACT)
            match_str = rec.actor;
        else if (search_type IS TG_SRCH_BY_CHAR)
            match_str = rec.character;
        else if (search_type IS TG_SRCH_BY_EPS)
            match_str = rec.episodes;

        if (File_TOS) {
            if ((fp = fopen (TG_FILE_ACT_TOS, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR (tg_streq (srch_str, match_str, m_str_len))) {
                        if (tg_display_act (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }

        if (File_TAS) {
            if ((fp = fopen (TG_FILE_ACT_TAS, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR (tg_streq (srch_str, match_str, m_str_len))) {
                        if (tg_display_act (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }

        if (File_TMS) {
            if ((fp = fopen (TG_FILE_ACT_TMS, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR (tg_streq (srch_str, match_str, m_str_len))) {
                        if (tg_display_act (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }

        if (File_TNG) {
            if ((fp = fopen (TG_FILE_ACT_TNG, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR (tg_streq (srch_str, match_str, m_str_len))) {
                        if (tg_display_act (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }

        if (File_DS9) {
            if ((fp = fopen (TG_FILE_ACT_DS9, "r")) ISNT NULL) {
                while (fread (&rec, ACTREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR (tg_streq (srch_str, match_str, m_str_len))) {
                        if (tg_display_act (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }
    }

    printf ("\n\nNo more matches.  Press enter to continue.");
    fgets (srch_str, MAX_BUF_LEN, stdin);
}


/* tg_search_eps - Searches through the selected Episode database(s) (all in
                    Eps, if UseMem, else in the selected File_* files),
                    for a particular episode record, which matches either
                    the entered title, number, airdate, stardate, writer,
                    director, synopsis, or all of the above, depending
                    on passed search_type.
*/

void tg_search_eps (search_type)
    int        search_type;           /* the type of search being done     */
{
    char    t_str[MAX_BUF_LEN+1];     /* buffer to hold input title str    */
    char    num_str[MAX_BUF_LEN+1];   /* buffer to hold input number str   */
    char    ad_str[MAX_BUF_LEN+1];    /* buffer to hold input airdate str  */
    char    sd_str[MAX_BUF_LEN+1];    /* buffer to hold input stardate str */
    char    wrt_str[MAX_BUF_LEN+1];   /* buffer to hold input writer str   */
    char    dir_str[MAX_BUF_LEN+1];   /* buffer to hold input director str */
    char    syn_str[MAX_BUF_LEN+1];   /* buffer to hold input synopsis str */
    int     i;                        /* loop counter                      */
    FILE    *fp;                      /* file pointer; for NOT UseMem      */
    struct epsrec_struct    rec;      /* a single episode record           */

    t_str[0] = num_str[0] = ad_str[0] = sd_str[0] = wrt_str[0] = dir_str[0] = syn_str[0] = '\0';

    printf ("\f\n\n");

    if (search_type IS TG_SRCH_BY_MULT) {
        printf ("Enter information for all fields to search on, or just press ENTER to not\n");
        printf ("use any of the fields prompted for.\n\n");
    }

    if ((search_type IS TG_SRCH_BY_TITLE) OR (search_type IS TG_SRCH_BY_MULT)) {
        printf ("Enter the episode title: ");
        fgets (t_str, MAX_BUF_LEN, stdin);
        t_str[strlen (t_str) - 1] = '\0';        /* get rid of '\n' */
    }
    if ((search_type IS TG_SRCH_BY_NUM) OR (search_type IS TG_SRCH_BY_MULT)) {
        printf ("Enter the episode number: ");
        fgets (num_str, MAX_BUF_LEN, stdin);
        num_str[strlen (num_str) - 1] = '\0';        /* get rid of '\n' */
    }
    if ((search_type IS TG_SRCH_BY_AIRDATE) OR (search_type IS TG_SRCH_BY_MULT)) {
        printf ("Enter the episode airdate: ");
        fgets (ad_str, MAX_BUF_LEN, stdin);
        ad_str[strlen (ad_str) - 1] = '\0';        /* get rid of '\n' */
    }
    if ((search_type IS TG_SRCH_BY_STARDATE) OR (search_type IS TG_SRCH_BY_MULT)) {
        printf ("Enter the episode stardate: ");
        fgets (sd_str, MAX_BUF_LEN, stdin);
        sd_str[strlen (sd_str) - 1] = '\0';        /* get rid of '\n' */
    }
    if ((search_type IS TG_SRCH_BY_WRITER) OR (search_type IS TG_SRCH_BY_MULT)) {
        printf ("Enter the episode writer: ");
        fgets (wrt_str, MAX_BUF_LEN, stdin);
        wrt_str[strlen (wrt_str) - 1] = '\0';        /* get rid of '\n' */
    }
    if ((search_type IS TG_SRCH_BY_DIRECTOR) OR (search_type IS TG_SRCH_BY_MULT)) {
        printf ("Enter the episode director: ");
        fgets (dir_str, MAX_BUF_LEN, stdin);
        dir_str[strlen (dir_str) - 1] = '\0';        /* get rid of '\n' */
    }
    if ((search_type IS TG_SRCH_BY_SYNOP) OR (search_type IS TG_SRCH_BY_MULT)) {
        printf ("Enter the episode synopsis (keyword): ");
        fgets (syn_str, MAX_BUF_LEN, stdin);
        syn_str[strlen (syn_str) - 1] = '\0';        /* get rid of '\n' */
    }



    if (UseMem) {
        for (i = 0; i < Num_Eps; i++) {
            if ((search_type IS TG_SRCH_BY_NONE) OR
                (tg_streq (t_str, Eps[i].title, TG_TITLE_LEN) AND
                 tg_streq (num_str, Eps[i].number, TG_NUMBER_LEN) AND
                 tg_streq (ad_str, Eps[i].airdate, TG_AIRDATE_LEN) AND
                 tg_streq (sd_str, Eps[i].stardate, TG_STARDATE_LEN) AND
                 tg_streq (wrt_str, Eps[i].writer, TG_WRITER_LEN) AND
                 tg_streq (dir_str, Eps[i].director, TG_DIRECTOR_LEN) AND
                 (tg_streq (syn_str, Eps[i].synop1, TG_SYNOP1_LEN) OR
                  tg_streq (syn_str, Eps[i].synop2, TG_SYNOP2_LEN) OR
                  tg_streq (syn_str, Eps[i].synop3, TG_SYNOP3_LEN)))) {

                if (tg_display_eps (&(Eps[i])))
                    return;
            }
        }
    } else {
        if (File_TOS) {
            if ((fp = fopen (TG_FILE_EPS_TOS, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR
                        (tg_streq (t_str, rec.title, TG_TITLE_LEN) AND
                         tg_streq (num_str, rec.number, TG_NUMBER_LEN) AND
                         tg_streq (ad_str, rec.airdate, TG_AIRDATE_LEN) AND
                         tg_streq (sd_str, rec.stardate, TG_STARDATE_LEN) AND
                         tg_streq (wrt_str, rec.writer, TG_WRITER_LEN) AND
                         tg_streq (dir_str, rec.director, TG_DIRECTOR_LEN) AND
                         (tg_streq (syn_str, rec.synop1, TG_SYNOP1_LEN) OR
                          tg_streq (syn_str, rec.synop2, TG_SYNOP2_LEN) OR
                          tg_streq (syn_str, rec.synop3, TG_SYNOP3_LEN)))) {

                        if (tg_display_eps (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }

        if (File_TAS) {
            if ((fp = fopen (TG_FILE_EPS_TAS, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR
                        (tg_streq (t_str, rec.title, TG_TITLE_LEN) AND
                         tg_streq (num_str, rec.number, TG_NUMBER_LEN) AND
                         tg_streq (ad_str, rec.airdate, TG_AIRDATE_LEN) AND
                         tg_streq (sd_str, rec.stardate, TG_STARDATE_LEN) AND
                         tg_streq (wrt_str, rec.writer, TG_WRITER_LEN) AND
                         tg_streq (dir_str, rec.director, TG_DIRECTOR_LEN) AND
                         (tg_streq (syn_str, rec.synop1, TG_SYNOP1_LEN) OR
                          tg_streq (syn_str, rec.synop2, TG_SYNOP2_LEN) OR
                          tg_streq (syn_str, rec.synop3, TG_SYNOP3_LEN)))) {

                        if (tg_display_eps (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }

        if (File_TMS) {
            if ((fp = fopen (TG_FILE_EPS_TMS, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR
                        (tg_streq (t_str, rec.title, TG_TITLE_LEN) AND
                         tg_streq (num_str, rec.number, TG_NUMBER_LEN) AND
                         tg_streq (ad_str, rec.airdate, TG_AIRDATE_LEN) AND
                         tg_streq (sd_str, rec.stardate, TG_STARDATE_LEN) AND
                         tg_streq (wrt_str, rec.writer, TG_WRITER_LEN) AND
                         tg_streq (dir_str, rec.director, TG_DIRECTOR_LEN) AND
                         (tg_streq (syn_str, rec.synop1, TG_SYNOP1_LEN) OR
                          tg_streq (syn_str, rec.synop2, TG_SYNOP2_LEN) OR
                          tg_streq (syn_str, rec.synop3, TG_SYNOP3_LEN)))) {

                        if (tg_display_eps (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }

        if (File_TNG) {
            if ((fp = fopen (TG_FILE_EPS_TNG, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR
                        (tg_streq (t_str, rec.title, TG_TITLE_LEN) AND
                         tg_streq (num_str, rec.number, TG_NUMBER_LEN) AND
                         tg_streq (ad_str, rec.airdate, TG_AIRDATE_LEN) AND
                         tg_streq (sd_str, rec.stardate, TG_STARDATE_LEN) AND
                         tg_streq (wrt_str, rec.writer, TG_WRITER_LEN) AND
                         tg_streq (dir_str, rec.director, TG_DIRECTOR_LEN) AND
                         (tg_streq (syn_str, rec.synop1, TG_SYNOP1_LEN) OR
                          tg_streq (syn_str, rec.synop2, TG_SYNOP2_LEN) OR
                          tg_streq (syn_str, rec.synop3, TG_SYNOP3_LEN)))) {

                        if (tg_display_eps (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }

        if (File_DS9) {
            if ((fp = fopen (TG_FILE_EPS_DS9, "r")) ISNT NULL) {
                while (fread (&rec, EPSREC_LEN, 1, fp) IS 1) {
                    if ((search_type IS TG_SRCH_BY_NONE) OR
                        (tg_streq (t_str, rec.title, TG_TITLE_LEN) AND
                         tg_streq (num_str, rec.number, TG_NUMBER_LEN) AND
                         tg_streq (ad_str, rec.airdate, TG_AIRDATE_LEN) AND
                         tg_streq (sd_str, rec.stardate, TG_STARDATE_LEN) AND
                         tg_streq (wrt_str, rec.writer, TG_WRITER_LEN) AND
                         tg_streq (dir_str, rec.director, TG_DIRECTOR_LEN) AND
                         (tg_streq (syn_str, rec.synop1, TG_SYNOP1_LEN) OR
                          tg_streq (syn_str, rec.synop2, TG_SYNOP2_LEN) OR
                          tg_streq (syn_str, rec.synop3, TG_SYNOP3_LEN)))) {

                        if (tg_display_eps (&rec)) {
                            fclose (fp);
                            return;
                        }
                    }
                }

                fclose (fp);
            }
        }
    }

    printf ("\n\nNo more matches.  Press enter to continue.");
    fgets (t_str, MAX_BUF_LEN, stdin);
}

