/**************************************************************************/
/* trekguru.c - The main code file for the Unix/C version of the "Trek    */
/*                Guru" program.                                          */
/*                                                                        */
/*                Original creator: Rob Seace (ras@world.std.com)         */
/*                                                                        */
/*        Note: If you make ANY changes at all to any of the code, PLEASE */
/*              make note of it with comments, as well as in the "README" */
/*              file, especially if re-distributing the new code.         */
/*                                                                        */
/*        This is really the only rule I have.  Anything you want to do   */
/*        with this code, go right ahead and do it.  I declare it Public  */
/*        Domain code.                                                    */
/*                                                                        */
/*        Note: Sometime in the future, I hope to add TNG and DS9 info to */
/*              this program (it currently only has TOS, TAS, and TMS     */
/*              info).  But, I'm adding the support for this future info  */
/*              into the code now, so that I'll only have to distribute   */
/*              the new datafiles when (if) I eventually create them.  (I */
/*              love to program, but I HATE to enter data. ;-))           */
/**************************************************************************/


#include "trekguru.h"


#define PROG_VERSION    "1.00-C"                    /* program version    */


actrec    Acts;       /* global array of actor info; actrec is pointer    */
epsrec    Eps;        /* global array of episode info; epsrec is pointer  */

int        Num_Acts;  /* number of items in Acts array                    */
int        Num_Eps;   /* number of items in Eps array                     */

int        UseMem;    /* boolean; TRUE => use memory to store all info    */
                      /*         FALSE => search directly from file; slow */

int        File_TOS;  /* boolean; TRUE => use TOS files, if NOT UseMem    */
int        File_TAS;  /* boolean; TRUE => use TAS files, if NOT UseMem    */
int        File_TMS;  /* boolean; TRUE => use TMS files, if NOT UseMem    */
int        File_TNG;  /* boolean; TRUE => use TNG files, if NOT UseMem    */
int        File_DS9;  /* boolean; TRUE => use DS9 files, if NOT UseMem    */

char    *DatDir;    /* Directory the datafiles are in                    */


/* tg_usage - Function to print out usage message, when "?" is first parameter.
*/

void tg_usage (progname)
    char    *progname;            /* name of executable for this program    */
{
    fprintf (stderr, "\nV%s  Usage:  %s [+f] [d=<dir>]\n\n", PROG_VERSION, progname);

    fprintf (stderr, "+f(ile)       Use file access for all searching.  Default is to load all\n");
    fprintf (stderr, "              info into memory after a series (or 'all series') has been\n");
    fprintf (stderr, "              selected from the Main Menu.  Use this option if you are\n");
    fprintf (stderr, "              short on memory.  Searches are very slow this way, though.\n");
    fprintf (stderr, "              You may also need to use this option on systems where there\n");
    fprintf (stderr, "              is some set limit on data memory (like QNX's 64k limit).\n\n");

    fprintf (stderr, "d=<data_dir>  The directory the data files are in (if not current dir).\n\n");
    exit (0);
}



main (argc, argv)
    int        argc;
    char    *argv[];
{
    char    actfile[MAX_BUF_LEN+1];  /* name of actor file               */
    char    epsfile[MAX_BUF_LEN+1];  /* name of episode file             */
    int     choice;             /* user-selected Main Menu choice        */
    int     last_sub;           /* last submenu choice user made         */
                                /* (If same one is re-selected again, it */
                                /* won't bother to re-load data, since   */
                                /* it is already loaded.)                */
static    char    *main_menu_choices[] = {
            "Exit the program.",
            "Display help information.",
            "The Original Series.",
            "The Animated Series.",
            "The Movie Series.",
            "The Next Generation.",          /* TNG & DS9 info not yet    */
            "Deep Space Nine.",              /* available, but for future */
            "All Available Series.",
             NULL};               /* Main Menu choices (for tg_menu())    */


    UseMem = TRUE;
    File_TOS = File_TAS = File_TMS = File_TNG = File_DS9 = FALSE;
    Acts = (actrec) NULL;
    Eps = (epsrec) NULL;
    Num_Acts = Num_Eps = 0;
    last_sub = 0;
    DatDir = NULL;

    if (NOT argc)
        tg_usage (argv[0]);

    while (--argc) {
        if (NOT strcmp (argv[argc], "?"))
            tg_usage (argv[0]);
        else if ((NOT strncmp (argv[argc], "+f", 2)) OR (NOT strncmp (argv[argc], "+F", 2)))
            UseMem = FALSE;
        else if ((NOT strncmp (argv[argc], "d=", 2)) OR (NOT strncmp (argv[argc], "D=", 2)))
            DatDir = argv[argc] + 2;
        else {
            fprintf (stderr, "\nUnknown option: %s.\n\n", argv[argc]);
            exit (-1);
        }
    }

    while (choice = tg_menu (main_menu_choices)) {    /* while choice isn't "0" */
        if (choice IS 0)        /* should never happen */
            break;
        else if (choice IS 1)
            tg_help_main ();
        else if (choice IS 2) {
            strcpy (actfile, TG_FILE_ACT_TOS);
            strcpy (epsfile, TG_FILE_EPS_TOS);
            if (UseMem AND (last_sub ISNT 2))
                tg_load_one (actfile, epsfile);
            else if (NOT UseMem) {
                File_TOS = TRUE;
                File_TAS = File_TMS = File_TNG = File_DS9 = FALSE;
            }
            last_sub = choice;
            if ((NOT UseMem) OR ((Acts ISNT NULL) AND (Eps ISNT NULL)))
                tg_do_sub ();
        } else if (choice IS 3) {
            strcpy (actfile, TG_FILE_ACT_TAS);
            strcpy (epsfile, TG_FILE_EPS_TAS);
            if (UseMem AND (last_sub ISNT 3))
                tg_load_one (actfile, epsfile);
            else if (NOT UseMem) {
                File_TAS = TRUE;
                File_TOS = File_TMS = File_TNG = File_DS9 = FALSE;
            }
            last_sub = choice;
            if ((NOT UseMem) OR ((Acts ISNT NULL) AND (Eps ISNT NULL)))
                tg_do_sub ();
        } else if (choice IS 4) {
            strcpy (actfile, TG_FILE_ACT_TMS);
            strcpy (epsfile, TG_FILE_EPS_TMS);
            if (UseMem AND (last_sub ISNT 4))
                tg_load_one (actfile, epsfile);
            else if (NOT UseMem) {
                File_TMS = TRUE;
                File_TOS = File_TAS = File_TNG = File_DS9 = FALSE;
            }
            last_sub = choice;
            if ((NOT UseMem) OR ((Acts ISNT NULL) AND (Eps ISNT NULL)))
                tg_do_sub ();
        } else if (choice IS 5) {
            strcpy (actfile, TG_FILE_ACT_TNG);
            strcpy (epsfile, TG_FILE_EPS_TNG);
            if (UseMem AND (last_sub ISNT 5))
                tg_load_one (actfile, epsfile);
            else if (NOT UseMem) {
                File_TNG = TRUE;
                File_TOS = File_TAS = File_TMS = File_DS9 = FALSE;
            }
            last_sub = choice;
            if ((NOT UseMem) OR ((Acts ISNT NULL) AND (Eps ISNT NULL)))
                tg_do_sub ();
        } else if (choice IS 6) {
            strcpy (actfile, TG_FILE_ACT_DS9);
            strcpy (epsfile, TG_FILE_EPS_DS9);
            if (UseMem AND (last_sub ISNT 6))
                tg_load_one (actfile, epsfile);
            else if (NOT UseMem) {
                File_DS9 = TRUE;
                File_TOS = File_TAS = File_TMS = File_TNG = FALSE;
            }
            last_sub = choice;
            if ((NOT UseMem) OR ((Acts ISNT NULL) AND (Eps ISNT NULL)))
                tg_do_sub ();
        } else if (choice IS 7) {
            if (UseMem AND (last_sub ISNT 7))
                tg_load_all ();
            else if (NOT UseMem)
                File_TOS = File_TAS = File_TMS = File_TNG = File_DS9 = TRUE;
            last_sub = choice;
            if ((NOT UseMem) OR ((Acts ISNT NULL) AND (Eps ISNT NULL)))
                tg_do_sub ();
        } else    /* should never happen */
            printf ("\07Bad choice: %d\n", choice);
    }

    if (Acts ISNT NULL)
        free (Acts);
    if (Eps ISNT NULL)
        free (Eps);

    printf ("\n\nThanks for using Trek Guru.  Live Long And Prosper.\n\n");

    exit (0);
}

