/****************************************************************************/
/* trekguru.h - Header file for Unix/C version of "Trek Guru".              */
/*                                                                          */
/*                Original creator: Rob Seace (ras@world.std.com)           */
/*                                                                          */
/*        Note: If you make ANY changes at all to any of the code, PLEASE   */
/*              mark it all clearly, especially, if re-distributing it.     */
/****************************************************************************/

#ifndef H_TREKGURU
#define H_TREKGURU

#include <stdio.h>
#include <string.h>


#define MAX_BUF_LEN        128        /* maximum length of a buffer          */

#define TG_SCR_LINES       18         /* # lines of listed data per screen   */
#define TG_PG_LINES        50         /* # lines of listed data per page     */


/* If not ANSI compiler, SEEK_SET, SEEK_CUR, and SEEK_END constants not
   defined for fseek() use...
*/

#define SEEK_SET	0
#define SEEK_CUR	1
#define SEEK_END	2


/* Field length definitions for actrec. */

#define TG_ACTOR_LEN        30
#define TG_CHAR_LEN         30
#define TG_EPS_LEN          68

/* actrec - Structure containing information about actors and the characters
            they play, and the episodes that character (played by that actor)
            has appeared in.
*/

struct actrec_struct {
    char    actor[TG_ACTOR_LEN];        /* Name of an actor                */
    char    character[TG_CHAR_LEN];     /* Name of the character           */
    char    episodes[TG_EPS_LEN];       /* Prod numbers of episodes        */
};

typedef struct actrec_struct    *actrec;

#define    ACTREC_LEN        (sizeof (struct actrec_struct))


/* Field length definitions of epsrec. */

#define TG_TITLE_LEN        70
#define TG_NUMBER_LEN       8
#define TG_AIRDATE_LEN      10
#define TG_STARDATE_LEN     10
#define TG_SYNOP1_LEN       80
#define TG_SYNOP2_LEN       80
#define TG_SYNOP3_LEN       40
#define TG_WRITER_LEN       70
#define TG_DIRECTOR_LEN     56

/* epsrec - Structure containing information about episodes of the show.
*/

struct epsrec_struct {
    char    title[TG_TITLE_LEN];          /* Name of an episode            */
    char    number[TG_NUMBER_LEN];        /* Production number of the ep.  */
    char    airdate[TG_AIRDATE_LEN];      /* Original air date of the ep.  */
    char    stardate[TG_STARDATE_LEN];    /* Stardate of the episode       */
    char    synop1[TG_SYNOP1_LEN];        /* First line of synopsis        */
    char    synop2[TG_SYNOP2_LEN];        /* Second line of synopsis       */
    char    synop3[TG_SYNOP3_LEN];        /* Third line of synopsis        */
    char    writer[TG_WRITER_LEN];        /* Writer(s) of the episode      */
    char    director[TG_DIRECTOR_LEN];    /* Director of the episode       */
};

typedef struct epsrec_struct    *epsrec;

#define EPSREC_LEN        (sizeof (struct epsrec_struct))


/* File name constants.  The tg_add_dir() function appends the input    */
/* data directory, DatDir, to the beginning of the filenames, if one    */
/* was entered, and returns a pointer to the resultant string.          */

#define TG_FILE_EPS_TOS        (tg_add_dir ("tos_eps.dat"))
#define TG_FILE_ACT_TOS        (tg_add_dir ("tos_act.dat"))
#define TG_FILE_EPS_TAS        (tg_add_dir ("tas_eps.dat"))
#define TG_FILE_ACT_TAS        (tg_add_dir ("tas_act.dat"))
#define TG_FILE_EPS_TMS        (tg_add_dir ("tms_eps.dat"))
#define TG_FILE_ACT_TMS        (tg_add_dir ("tms_act.dat"))
#define TG_FILE_EPS_TNG        (tg_add_dir ("tng_eps.dat"))
#define TG_FILE_ACT_TNG        (tg_add_dir ("tng_act.dat"))
#define TG_FILE_EPS_DS9        (tg_add_dir ("ds9_eps.dat"))
#define TG_FILE_ACT_DS9        (tg_add_dir ("ds9_act.dat"))


/* Search types. */

#define TG_SRCH_BY_NONE        0

#define TG_SRCH_BY_ACT         1
#define TG_SRCH_BY_CHAR        2
#define TG_SRCH_BY_EPS         3

#define TG_SRCH_BY_TITLE      101
#define TG_SRCH_BY_NUM        102
#define TG_SRCH_BY_AIRDATE    103
#define TG_SRCH_BY_STARDATE   104
#define TG_SRCH_BY_WRITER     105
#define TG_SRCH_BY_DIRECTOR   106
#define TG_SRCH_BY_SYNOP      107
#define TG_SRCH_BY_MULT       108


/* Extern declarations. */

extern    actrec     Acts;
extern    epsrec     Eps;
extern    int        Num_Acts;
extern    int        Num_Eps;
extern    int        UseMem;
extern    int        File_TOS;
extern    int        File_TAS;
extern    int        File_TMS;
extern    int        File_TNG;
extern    int        File_DS9;
extern    char      *DatDir;


/* Function declarations.  (No prototypes, in case no ANSI compiler.) */

int tg_display_act ();
int tg_display_eps ();
void tg_save_act ();
void tg_save_eps ();

void tg_list_acts ();
void tg_list_eps ();

void tg_load_one ();
void tg_load_all ();
void tg_fill_eps ();
void tg_fill_acts ();

void tg_search_act ();
void tg_search_eps ();

void tg_do_sub ();

int tg_menu ();
void tg_help_main ();
void tg_help_sub ();
int tg_streq ();
char *tg_add_dir ();



/* Some useful constants to make code easier to read. */

#define NOT       !
#define AND       &&
#define OR        ||
#define IS        ==
#define ISNT      !=
#define TRUE      1
#define FALSE     0

/* And, no flames from C hackers about how this makes the code sissified...
   I know, already...  But, where I work, we have to use #defined stuff
   like that in all our code, so I've gotten into the habit of using them
   all the time...  Plus, it DOES actually make the code a bit easier to
   read (as well as eliminating ye olde "="/"==" mistake... ;-))...
*/



#endif    /* H_TREKGURU */

